@@ -5,11 +5,10 @@
 #' argument, and multiple layers of markers can be added and toggled between
 #' using \code{control}. See [openair::polarPlot()] for more information.
 #'
-#' @seealso Directional analysis maps: [annulusMap()], [freqMap()],
-#'   [percentileMap()], [polarMap()], [pollroseMap()], [windroseMap()].
+#' @family directional analysis maps
 #'
-#' @param data A data frame. The data frame must contain the data to plot a
-#'   [openair::polarPlot()], which includes wind speed (\code{ws}), wind
+#' @param data A data frame. The data frame must contain the data to plot the
+#'   directional analysis marker, which includes wind speed (\code{ws}), wind
 #'   direction (\code{wd}), and the column representing the concentration of a
 #'   pollutant. In addition, \code{data} must include a decimal latitude and
 #'   longitude.
@@ -17,12 +16,14 @@
 #'   pollutants are specified, they can be toggled between using a "layer
 #'   control" interface.
 #' @param x The radial axis variable to plot.
-#' @param latitude The decimal latitude. If not provided, latitude will be
-#'   automatically inferred from data by looking for a column named \dQuote{lat}
-#'   or \dQuote{latitude} (case-insensitively).
-#' @param longitude The decimal longitude. If not provided, longitude will be
-#'   automatically inferred from data by looking for a column named
-#'   \dQuote{lon}, \dQuote{lng}, \dQuote{long}, or \dQuote{longitude}
+#' @param limits By default, each individual polar marker has its own colour
+#'   scale. The \code{limits} argument will force all markers to use the same
+#'   colour scale. The limits are set in the form \code{c(lower, upper)}, so
+#'   \code{limits = c(0, 100)} would force the plot limits to span 0-100.
+#' @param latitude,longitude The decimal latitude/longitude. If not provided,
+#'   will be automatically inferred from data by looking for a column named
+#'   \dQuote{lat}/\dQuote{latitude} or
+#'   \dQuote{lon}/\dQuote{lng}/\dQuote{long}/\dQuote{longitude}
 #'   (case-insensitively).
 #' @param control Column to be used for splitting the input data into different
 #'   groups which can be selected between using a "layer control" interface.
@@ -42,14 +43,19 @@
 #' @param cols The colours used for plotting.
 #' @param alpha The alpha transparency to use for the plotting surface (a value
 #'   between 0 and 1 with zero being fully transparent and 1 fully opaque).
-#' @param key Should the key of the plot be drawn. Default is \code{FALSE}.
+#' @param key Should a key for each marker be drawn? Default is \code{FALSE}.
+#' @param draw.legend When \code{limits} are specified, should a shared legend
+#'   be created at the side of the map? Default is \code{TRUE}.
+#' @param collapse.control Should the "layer control" interface be collapsed?
+#'   Defaults to \code{FALSE}.
 #' @param iconWidth The actual width of the plot on the map in pixels.
 #' @param iconHeight The actual height of the plot on the map in pixels.
 #' @param fig.width The width of the plots to be produced in inches.
 #' @param fig.height The height of the plots to be produced in inches.
 #' @param type Deprecated. Please use \code{label} and/or \code{popup} to label
 #'   different sites.
-#' @param ... Other arguments for [openair::polarPlot()].
+#' @inheritDotParams openair::polarPlot -mydata -pollutant -x -limits -type
+#'   -cols -key -alpha -plot
 #' @return A leaflet object.
 #' @export
 #'
@@ -64,6 +70,7 @@
 polarMap <- function(data,
                      pollutant = NULL,
                      x = "ws",
+                     limits = NULL,
                      latitude = NULL,
                      longitude = NULL,
                      control = NULL,
@@ -73,12 +80,15 @@ polarMap <- function(data,
                      cols = "jet",
                      alpha = 1,
                      key = FALSE,
+                     draw.legend = TRUE,
+                     collapse.control = FALSE,
                      iconWidth = 200,
                      iconHeight = 200,
-                     fig.width = 4,
-                     fig.height = 4,
+                     fig.width = 3.5,
+                     fig.height = 3.5,
                      type = NULL,
                      ...) {
+  # warn type
   if (!is.null(type)) {
     cli::cli_warn(c(
       "!" = "{.code type} is deprecated. Different sites are now automatically identified.",
@@ -95,6 +105,10 @@ polarMap <- function(data,
   latitude <- latlon$latitude
   longitude <- latlon$longitude
 
+  # deal with limits
+  theLimits <- limits
+  if (is.null(limits)) theLimits <- NA
+
   # prep data
   data <-
     prepMapData(
@@ -112,7 +126,7 @@ polarMap <- function(data,
   # define plotting function
   args <- list(...)
   fun <- function(...) {
-    rlang::exec(openair::polarPlot, x = x, !!!args, ...)
+    rlang::exec(openair::polarPlot, x = x, limits = theLimits, alpha = alpha, !!!args, ...)
   }
 
   # identify splitting column (defaulting to pollutant)
@@ -133,21 +147,39 @@ polarMap <- function(data,
     purrr::imap(
       .f = ~ create_icons(
         data = .x, fun = fun, pollutant = "conc", split = .y,
-        lat = latitude, lon = longitude, x = x, cols = cols, alpha = alpha,
+        lat = latitude, lon = longitude, x = x, cols = cols,
         key = key, fig.width = fig.width, fig.height = fig.height,
         iconWidth = iconWidth, iconHeight = iconHeight, ...
       )
     )
 
   # plot leaflet
-  makeMap(
-    data = data,
-    icons = icons,
-    provider = provider,
-    longitude = longitude,
-    latitude = latitude,
-    popup = popup,
-    label = label,
-    split_col = split_col
-  )
+  map <-
+    makeMap(
+      data = data,
+      icons = icons,
+      provider = provider,
+      longitude = longitude,
+      latitude = latitude,
+      popup = popup,
+      label = label,
+      split_col = split_col,
+      collapse = collapse.control
+    )
+
+  # add legend if limits are set
+  if (!is.null(limits) & all(!is.na(limits)) & draw.legend) {
+    map <-
+      leaflet::addLegend(
+        map,
+        title = quickTextHTML(paste(pollutant, collapse = ",<br>")),
+        pal = leaflet::colorNumeric(
+          palette = openair::openColours(scheme = cols),
+          domain = theLimits
+        ),
+        values = theLimits
+      )
+  }
+
+  map
 }
